@@ -53,7 +53,7 @@ extern struct function date_funs[];
 extern struct function busi_funs[];
 extern struct function string_funs[];
 extern struct function cells_funs[];
-extern char *instr;
+extern char *instruct;
 extern int parse_error;
 extern struct node *parse_return;
 extern void sort ();
@@ -392,7 +392,7 @@ parse_and_compile (string)
   int need_relax;
   int byte;
 
-  instr = string;
+  instruct = string;
   parse_error = 0;
   patches_used = 0;
   if (yyparse () || parse_error)
