@@ -18,8 +18,19 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #include <ctype.h>
 #include <errno.h>
+#include "sysdef.h"
+#ifndef _DEBUG_MALLOC_INC
+#define local_free free
+#else 
+static void
+local_free (p)
+     void * p;
+{
+  free (p);
+}
+#endif /* def _DEBUG_MALLOC_INC */
 #define obstack_chunk_alloc ck_malloc
-#define obstack_chunk_free free
+#define obstack_chunk_free local_free
 #include "obstack.h"
 #include "global.h"
 #include "cmd.h"
@@ -1139,11 +1150,6 @@ command_loop (prefix)
       /* Reset the keystate. */
       cur_keymap = the_cmd_frame->top_keymap;
 
-      /* If the input area holds a prompt from the last command,
-       * erase it. 
-       */
-      io_clear_input_before ();
-
 
       /* Some commands are prefix commands: they effect the 
        * user's state without beginnging a new command cyle.
@@ -1331,12 +1337,6 @@ command_loop (prefix)
        */
     got_command:
 
-      /* If there is anything left in the input area (e.g. old error message)
-       * get rid of it (but only if we're not executing a macro).
-       */
-      if (!rmac)
-	io_clear_input_after ();
-
       /* There are some commands that are implemented right here. */
       if (cur_cmd == break_cmd)
 	{
@@ -1809,7 +1809,15 @@ command_loop (prefix)
 		  {
 		    /* Edit a cell's formula. */
 		    CELL * cp = find_cell (curow, cucol);
+		    int do_init;
 		    ++prompt;
+		    if (*prompt == '\'')
+		      {
+			do_init = 0;
+			++prompt;
+		      }
+		    else
+		      do_init = 1;
 		    if (((!cp || GET_LCK (cp) == LCK_DEF)
 			 && (default_lock == LCK_LCK))
 			|| (cp && GET_LCK (cp) == LCK_LCK))
@@ -1823,9 +1831,12 @@ command_loop (prefix)
 		    the_cmd_frame->prev->_setcol = cucol;
 		    if (get_argument (prompt, &formula_style))
 		      {
-			init_arg_text (&the_cmd_arg,
-				       decomp (curow, cucol, cp));
-			decomp_free ();
+			if (do_init)
+			  {
+			    init_arg_text (&the_cmd_arg,
+					   decomp (curow, cucol, cp));
+			    decomp_free ();
+			  }
 			goto new_cycle;
 		      }
 		    goto next_arg;
