@@ -1,5 +1,6 @@
 
-/*  A Bison parser, made from /phydeaux/ni/lord/unsupported/oleo/getdate.y with Bison version GNU Bison version 1.22
+/*  A Bison parser, made from ./getdate.y
+ by  Bison version A2.6 (Andrew Consortium)
   */
 
 #define YYBISON 1  /* Identify Bison output.  */
@@ -18,9 +19,9 @@
 #define	tZONE	269
 #define	tDST	270
 
-#line 1 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 1 "./getdate.y"
 
-/* $Revision: 1.1 $
+/* $Revision: 1.1.1.1 $
 **
 **  Originally written by Steven M. Bellovin <smb@research.att.com> while
 **  at the University of North Carolina at Chapel Hill.  Later tweaked by
@@ -119,7 +120,7 @@ extern struct tm	*localtime();
 
 #if	!defined(lint) && !defined(SABER)
 static char RCS[] =
-	"$Header: /rel/cvsfiles/unsupported/oleo/getdate.y,v 1.1 94/06/03 16:18:42 lord Exp $";
+	"$Header: /home/kevin/CVS/oleo/getdate.y,v 1.1.1.1 1996/03/10 07:40:51 kevin Exp $";
 #endif	/* !defined(lint) && !defined(SABER) */
 
 
@@ -180,28 +181,11 @@ static time_t	gtdRelMonth;
 static time_t	gtdRelSeconds;
 
 
-#line 163 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 163 "./getdate.y"
 typedef union {
     time_t		Number;
     enum _MERIDIAN	Meridian;
 } YYSTYPE;
-
-#ifndef YYLTYPE
-typedef
-  struct gtdltype
-    {
-      int timestamp;
-      int first_line;
-      int first_column;
-      int last_line;
-      int last_column;
-      char *text;
-   }
-  gtdltype;
-
-#define YYLTYPE gtdltype
-#endif
-
 #include <stdio.h>
 
 #ifndef __cplusplus
@@ -280,11 +264,15 @@ static const short gtdrline[] = { 0,
    267,   272,   278,   282,   287,   291,   298,   302,   305,   308,
    311,   314,   317,   320,   323,   326,   329,   334,   362,   365
 };
+#endif
 
-static const char * const gtdtname[] = {   "$","error","$illegal.","tAGO","tDAY",
+
+#if YYDEBUG != 0
+
+static const char * const gtdtname[] = {   "$","error","$undefined.","tAGO","tDAY",
 "tDAYZONE","tID","tMERIDIAN","tMINUTE_UNIT","tMONTH","tMONTH_UNIT","tSEC_UNIT",
 "tSNUMBER","tUNUMBER","tZONE","tDST","':'","','","'/'","spec","item","time",
-"zone","day","date","rel","relunit","number","o_merid",""
+"zone","day","date","rel","relunit","number","o_merid", NULL
 };
 #endif
 
@@ -348,14 +336,14 @@ static const short gtdcheck[] = {     0,
     46
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/unsupported/lib/bison.simple"
+#line 3 "/usr/lib/bison.simple"
 
 /* Skeleton output parser for bison,
-   Copyright (C) 1984, 1989, 1990 Bob Corbett and Richard Stallman
+   Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 1, or (at your option)
+   the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -367,6 +355,10 @@ static const short gtdcheck[] = {     0,
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
+/* As a special exception, when this file is copied by Bison into a
+   Bison output file, you may use that output file without restriction.
+   This special exception was added by the Free Software Foundation
+   in version 1.24 of Bison.  */
 
 #ifndef alloca
 #ifdef __GNUC__
@@ -440,10 +432,18 @@ while (0)
 
 #ifdef YYPURE
 #ifdef YYLSP_NEEDED
+#ifdef YYLEX_PARAM
+#define YYLEX		gtdlex(&gtdlval, &gtdlloc, YYLEX_PARAM)
+#else
 #define YYLEX		gtdlex(&gtdlval, &gtdlloc)
+#endif
+#else /* not YYLSP_NEEDED */
+#ifdef YYLEX_PARAM
+#define YYLEX		gtdlex(&gtdlval, YYLEX_PARAM)
 #else
 #define YYLEX		gtdlex(&gtdlval)
 #endif
+#endif /* not YYLSP_NEEDED */
 #endif
 
 /* If nonreentrant, generate the variables here */
@@ -491,14 +491,14 @@ int gtdparse (void);
 #endif
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
-#define __gtd_bcopy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
+#define __gtd_memcpy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
 #ifndef __cplusplus
 
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__gtd_bcopy (from, to, count)
+__gtd_memcpy (from, to, count)
      char *from;
      char *to;
      int count;
@@ -516,7 +516,7 @@ __gtd_bcopy (from, to, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__gtd_bcopy (char *from, char *to, int count)
+__gtd_memcpy (char *from, char *to, int count)
 {
   register char *f = from;
   register char *t = to;
@@ -529,9 +529,24 @@ __gtd_bcopy (char *from, char *to, int count)
 #endif
 #endif
 
-#line 184 "/usr/unsupported/lib/bison.simple"
+#line 192 "/usr/lib/bison.simple"
+
+/* The user can define YYPARSE_PARAM as the name of an argument to be passed
+   into gtdparse.  The argument should have type void *.
+   It should actually point to an object.
+   Grammar actions can access the variable by casting it
+   to the proper pointer type.  */
+
+#ifdef YYPARSE_PARAM
+#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
+#else
+#define YYPARSE_PARAM
+#define YYPARSE_PARAM_DECL
+#endif
+
 int
-gtdparse()
+gtdparse(YYPARSE_PARAM)
+     YYPARSE_PARAM_DECL
 {
   register int gtdstate;
   register int gtdn;
@@ -647,12 +662,12 @@ gtdnewstate:
       if (gtdstacksize > YYMAXDEPTH)
 	gtdstacksize = YYMAXDEPTH;
       gtdss = (short *) alloca (gtdstacksize * sizeof (*gtdssp));
-      __gtd_bcopy ((char *)gtdss1, (char *)gtdss, size * sizeof (*gtdssp));
+      __gtd_memcpy ((char *)gtdss1, (char *)gtdss, size * sizeof (*gtdssp));
       gtdvs = (YYSTYPE *) alloca (gtdstacksize * sizeof (*gtdvsp));
-      __gtd_bcopy ((char *)gtdvs1, (char *)gtdvs, size * sizeof (*gtdvsp));
+      __gtd_memcpy ((char *)gtdvs1, (char *)gtdvs, size * sizeof (*gtdvsp));
 #ifdef YYLSP_NEEDED
       gtdls = (YYLTYPE *) alloca (gtdstacksize * sizeof (*gtdlsp));
-      __gtd_bcopy ((char *)gtdls1, (char *)gtdls, size * sizeof (*gtdlsp));
+      __gtd_memcpy ((char *)gtdls1, (char *)gtdls, size * sizeof (*gtdlsp));
 #endif
 #endif /* no gtdoverflow */
 
@@ -813,37 +828,37 @@ gtdreduce:
   switch (gtdn) {
 
 case 3:
-#line 181 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 181 "./getdate.y"
 {
 	    gtdHaveTime++;
 	;
     break;}
 case 4:
-#line 184 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 184 "./getdate.y"
 {
 	    gtdHaveZone++;
 	;
     break;}
 case 5:
-#line 187 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 187 "./getdate.y"
 {
 	    gtdHaveDate++;
 	;
     break;}
 case 6:
-#line 190 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 190 "./getdate.y"
 {
 	    gtdHaveDay++;
 	;
     break;}
 case 7:
-#line 193 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 193 "./getdate.y"
 {
 	    gtdHaveRel++;
 	;
     break;}
 case 9:
-#line 199 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 199 "./getdate.y"
 {
 	    gtdHour = gtdvsp[-1].Number;
 	    gtdMinutes = 0;
@@ -852,7 +867,7 @@ case 9:
 	;
     break;}
 case 10:
-#line 205 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 205 "./getdate.y"
 {
 	    gtdHour = gtdvsp[-3].Number;
 	    gtdMinutes = gtdvsp[-1].Number;
@@ -861,7 +876,7 @@ case 10:
 	;
     break;}
 case 11:
-#line 211 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 211 "./getdate.y"
 {
 	    gtdHour = gtdvsp[-3].Number;
 	    gtdMinutes = gtdvsp[-1].Number;
@@ -871,7 +886,7 @@ case 11:
 	;
     break;}
 case 12:
-#line 218 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 218 "./getdate.y"
 {
 	    gtdHour = gtdvsp[-5].Number;
 	    gtdMinutes = gtdvsp[-3].Number;
@@ -880,7 +895,7 @@ case 12:
 	;
     break;}
 case 13:
-#line 224 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 224 "./getdate.y"
 {
 	    gtdHour = gtdvsp[-5].Number;
 	    gtdMinutes = gtdvsp[-3].Number;
@@ -891,56 +906,56 @@ case 13:
 	;
     break;}
 case 14:
-#line 234 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 234 "./getdate.y"
 {
 	    gtdTimezone = gtdvsp[0].Number;
 	    gtdDSTmode = DSToff;
 	;
     break;}
 case 15:
-#line 238 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 238 "./getdate.y"
 {
 	    gtdTimezone = gtdvsp[0].Number;
 	    gtdDSTmode = DSTon;
 	;
     break;}
 case 16:
-#line 243 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 243 "./getdate.y"
 {
 	    gtdTimezone = gtdvsp[-1].Number;
 	    gtdDSTmode = DSTon;
 	;
     break;}
 case 17:
-#line 249 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 249 "./getdate.y"
 {
 	    gtdDayOrdinal = 1;
 	    gtdDayNumber = gtdvsp[0].Number;
 	;
     break;}
 case 18:
-#line 253 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 253 "./getdate.y"
 {
 	    gtdDayOrdinal = 1;
 	    gtdDayNumber = gtdvsp[-1].Number;
 	;
     break;}
 case 19:
-#line 257 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 257 "./getdate.y"
 {
 	    gtdDayOrdinal = gtdvsp[-1].Number;
 	    gtdDayNumber = gtdvsp[0].Number;
 	;
     break;}
 case 20:
-#line 263 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 263 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[-2].Number;
 	    gtdDay = gtdvsp[0].Number;
 	;
     break;}
 case 21:
-#line 267 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 267 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[-4].Number;
 	    gtdDay = gtdvsp[-2].Number;
@@ -948,7 +963,7 @@ case 21:
 	;
     break;}
 case 22:
-#line 272 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 272 "./getdate.y"
 {
 	    /* ISO 8601 format.  gtdgtd-mm-dd.  */
 	    gtdYear = gtdvsp[-2].Number;
@@ -957,14 +972,14 @@ case 22:
 	;
     break;}
 case 23:
-#line 278 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 278 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[-1].Number;
 	    gtdDay = gtdvsp[0].Number;
 	;
     break;}
 case 24:
-#line 282 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 282 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[-3].Number;
 	    gtdDay = gtdvsp[-2].Number;
@@ -972,14 +987,14 @@ case 24:
 	;
     break;}
 case 25:
-#line 287 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 287 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[0].Number;
 	    gtdDay = gtdvsp[-1].Number;
 	;
     break;}
 case 26:
-#line 291 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 291 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[-1].Number;
 	    gtdDay = gtdvsp[-2].Number;
@@ -987,68 +1002,68 @@ case 26:
 	;
     break;}
 case 27:
-#line 298 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 298 "./getdate.y"
 {
 	    gtdRelSeconds = -gtdRelSeconds;
 	    gtdRelMonth = -gtdRelMonth;
 	;
     break;}
 case 29:
-#line 305 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 305 "./getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number * gtdvsp[0].Number * 60L;
 	;
     break;}
 case 30:
-#line 308 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 308 "./getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number * gtdvsp[0].Number * 60L;
 	;
     break;}
 case 31:
-#line 311 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 311 "./getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[0].Number * 60L;
 	;
     break;}
 case 32:
-#line 314 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 314 "./getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number;
 	;
     break;}
 case 33:
-#line 317 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 317 "./getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number;
 	;
     break;}
 case 34:
-#line 320 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 320 "./getdate.y"
 {
 	    gtdRelSeconds++;
 	;
     break;}
 case 35:
-#line 323 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 323 "./getdate.y"
 {
 	    gtdRelMonth += gtdvsp[-1].Number * gtdvsp[0].Number;
 	;
     break;}
 case 36:
-#line 326 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 326 "./getdate.y"
 {
 	    gtdRelMonth += gtdvsp[-1].Number * gtdvsp[0].Number;
 	;
     break;}
 case 37:
-#line 329 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 329 "./getdate.y"
 {
 	    gtdRelMonth += gtdvsp[0].Number;
 	;
     break;}
 case 38:
-#line 334 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 334 "./getdate.y"
 {
 	    if (gtdHaveTime && gtdHaveDate && !gtdHaveRel)
 		gtdYear = gtdvsp[0].Number;
@@ -1077,20 +1092,20 @@ case 38:
 	;
     break;}
 case 39:
-#line 362 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 362 "./getdate.y"
 {
 	    gtdval.Meridian = MER24;
 	;
     break;}
 case 40:
-#line 365 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 365 "./getdate.y"
 {
 	    gtdval.Meridian = gtdvsp[0].Meridian;
 	;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 465 "/usr/unsupported/lib/bison.simple"
+#line 487 "/usr/lib/bison.simple"
 
   gtdvsp -= gtdlen;
   gtdssp -= gtdlen;
@@ -1286,7 +1301,7 @@ gtderrhandle:
   gtdstate = gtdn;
   goto gtdnewstate;
 }
-#line 370 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
+#line 370 "./getdate.y"
 
 
 /* Month and day table. */
