@@ -58,7 +58,9 @@ static void record_damage ();
 #ifdef __STDC__
 extern char * x_get_string_resource (XrmDatabase, char *, char *);
 extern XrmDatabase x_load_resources (Display *, char *, char *);
+#ifndef __linux__
 extern char * getenv (const char *);
+#endif /* not __linux__ */
 #else
 extern char * x_get_string_resource ();
 extern XrmDatabase x_load_resources ();
