@@ -1,5 +1,6 @@
 
-/*  A Bison parser, made from /phydeaux/ni/lord/unsupported/oleo/parse.y with Bison version GNU Bison version 1.22
+/*  A Bison parser, made from ./parse.y
+ by  Bison version A2.6 (Andrew Consortium)
   */
 
 #define YYBISON 1  /* Identify Bison output.  */
@@ -27,7 +28,7 @@
 #define	L_NE	278
 #define	L_GE	279
 
-#line 1 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 1 "./parse.y"
 
 /*	Copyright (C) 1990, 1992, 1993 Free Software Foundation, Inc.
 
@@ -46,7 +47,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with Oleo; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
-#line 41 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 41 "./parse.y"
 
 #include "funcdef.h"
 
@@ -86,27 +87,10 @@ YYSTYPE make_list (YYSTYPE, YYSTYPE);
 YYSTYPE make_list ();
 #endif
 
-char *instr;
+char *instruct;
 int parse_error = 0;
 extern struct obstack tmp_mem;
 
-
-#ifndef YYLTYPE
-typedef
-  struct yyltype
-    {
-      int timestamp;
-      int first_line;
-      int first_column;
-      int last_line;
-      int last_column;
-      char *text;
-   }
-  yyltype;
-
-#define YYLTYPE yyltype
-#endif
-
 #ifndef YYSTYPE
 #define YYSTYPE int
 #endif
@@ -200,12 +184,16 @@ static const short yyrline[] = { 0,
    214,   218,   222,   226,   241,   245,   247,   255,   262,   264,
    268,   269,   272,   274,   278,   280
 };
+#endif
 
-static const char * const yytname[] = {   "$","error","$illegal.","'?'","':'",
+
+#if YYDEBUG != 0
+
+static const char * const yytname[] = {   "$","error","$undefined.","'?'","':'",
 "'&'","'='","NE","'<'","LE","'>'","GE","'+'","'-'","'*'","'/'","'%'","'^'","NEG",
 "'!'","L_CELL","L_RANGE","L_VAR","L_CONST","L_FN0","L_FN1","L_FN2","L_FN3","L_FN4",
 "L_FNN","L_FN1R","L_FN2R","L_FN3R","L_FN4R","L_FNNR","L_LE","L_NE","L_GE","'('",
-"')'","','","line","exp","exp_list","range_exp","range_exp_list","cell",""
+"')'","','","line","exp","exp_list","range_exp","range_exp_list","cell", NULL
 };
 #endif
 
@@ -391,14 +379,14 @@ static const short yycheck[] = {     0,
     14,    15,    16,    17
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/unsupported/lib/bison.simple"
+#line 3 "/usr/lib/bison.simple"
 
 /* Skeleton output parser for bison,
-   Copyright (C) 1984, 1989, 1990 Bob Corbett and Richard Stallman
+   Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 1, or (at your option)
+   the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -410,6 +398,10 @@ static const short yycheck[] = {     0,
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
+/* As a special exception, when this file is copied by Bison into a
+   Bison output file, you may use that output file without restriction.
+   This special exception was added by the Free Software Foundation
+   in version 1.24 of Bison.  */
 
 #ifndef alloca
 #ifdef __GNUC__
@@ -483,10 +475,18 @@ while (0)
 
 #ifdef YYPURE
 #ifdef YYLSP_NEEDED
+#ifdef YYLEX_PARAM
+#define YYLEX		yylex(&yylval, &yylloc, YYLEX_PARAM)
+#else
 #define YYLEX		yylex(&yylval, &yylloc)
+#endif
+#else /* not YYLSP_NEEDED */
+#ifdef YYLEX_PARAM
+#define YYLEX		yylex(&yylval, YYLEX_PARAM)
 #else
 #define YYLEX		yylex(&yylval)
 #endif
+#endif /* not YYLSP_NEEDED */
 #endif
 
 /* If nonreentrant, generate the variables here */
@@ -534,14 +534,14 @@ int yyparse (void);
 #endif
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
-#define __yy_bcopy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
+#define __yy_memcpy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
 #ifndef __cplusplus
 
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_bcopy (from, to, count)
+__yy_memcpy (from, to, count)
      char *from;
      char *to;
      int count;
@@ -559,7 +559,7 @@ __yy_bcopy (from, to, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_bcopy (char *from, char *to, int count)
+__yy_memcpy (char *from, char *to, int count)
 {
   register char *f = from;
   register char *t = to;
@@ -572,9 +572,24 @@ __yy_bcopy (char *from, char *to, int count)
 #endif
 #endif
 
-#line 184 "/usr/unsupported/lib/bison.simple"
+#line 192 "/usr/lib/bison.simple"
+
+/* The user can define YYPARSE_PARAM as the name of an argument to be passed
+   into yyparse.  The argument should have type void *.
+   It should actually point to an object.
+   Grammar actions can access the variable by casting it
+   to the proper pointer type.  */
+
+#ifdef YYPARSE_PARAM
+#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
+#else
+#define YYPARSE_PARAM
+#define YYPARSE_PARAM_DECL
+#endif
+
 int
-yyparse()
+yyparse(YYPARSE_PARAM)
+     YYPARSE_PARAM_DECL
 {
   register int yystate;
   register int yyn;
@@ -690,12 +705,12 @@ yynewstate:
       if (yystacksize > YYMAXDEPTH)
 	yystacksize = YYMAXDEPTH;
       yyss = (short *) alloca (yystacksize * sizeof (*yyssp));
-      __yy_bcopy ((char *)yyss1, (char *)yyss, size * sizeof (*yyssp));
+      __yy_memcpy ((char *)yyss1, (char *)yyss, size * sizeof (*yyssp));
       yyvs = (YYSTYPE *) alloca (yystacksize * sizeof (*yyvsp));
-      __yy_bcopy ((char *)yyvs1, (char *)yyvs, size * sizeof (*yyvsp));
+      __yy_memcpy ((char *)yyvs1, (char *)yyvs, size * sizeof (*yyvsp));
 #ifdef YYLSP_NEEDED
       yyls = (YYLTYPE *) alloca (yystacksize * sizeof (*yylsp));
-      __yy_bcopy ((char *)yyls1, (char *)yyls, size * sizeof (*yylsp));
+      __yy_memcpy ((char *)yyls1, (char *)yyls, size * sizeof (*yylsp));
 #endif
 #endif /* no yyoverflow */
 
@@ -856,84 +871,84 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 87 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 87 "./parse.y"
 { parse_return=yyvsp[0]; ;
     break;}
 case 2:
-#line 88 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 88 "./parse.y"
 {
 		if(!parse_error)
 			parse_error=PARSE_ERR;
 		parse_return=0; ;
     break;}
 case 5:
-#line 96 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 96 "./parse.y"
 {
 		yyval=yyvsp[-2]; ;
     break;}
 case 6:
-#line 98 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 98 "./parse.y"
 {
 		(yyvsp[-3])->n_x.v_subs[0]=yyvsp[-1];
 		(yyvsp[-3])->n_x.v_subs[1]=(struct node *)0;
 		yyval=yyvsp[-3]; ;
     break;}
 case 7:
-#line 102 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 102 "./parse.y"
 {
 		(yyvsp[-5])->n_x.v_subs[0]=yyvsp[-3];
 		(yyvsp[-5])->n_x.v_subs[1]=yyvsp[-1];
 		yyval=yyvsp[-5]; ;
     break;}
 case 8:
-#line 106 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 106 "./parse.y"
 {
 		(yyvsp[-7])->n_x.v_subs[0]=make_list(yyvsp[-5],yyvsp[-3]);
  		(yyvsp[-7])->n_x.v_subs[1]=yyvsp[-1];
  		yyval=yyvsp[-7];;
     break;}
 case 9:
-#line 110 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 110 "./parse.y"
 {
 		(yyvsp[-9])->n_x.v_subs[0]=make_list(yyvsp[-7],yyvsp[-5]);
  		(yyvsp[-9])->n_x.v_subs[1]=make_list(yyvsp[-3],yyvsp[-1]);
  		yyval=yyvsp[-9];;
     break;}
 case 10:
-#line 114 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 114 "./parse.y"
 {
 		(yyvsp[-3])->n_x.v_subs[0]=(struct node *)0;
 		(yyvsp[-3])->n_x.v_subs[1]=yyvsp[-1];
 		yyval=yyvsp[-3]; ;
     break;}
 case 11:
-#line 118 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 118 "./parse.y"
 {
 		yyvsp[-3]->n_x.v_subs[0]=yyvsp[-1];
 		yyval=yyvsp[-3]; ;
     break;}
 case 12:
-#line 121 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 121 "./parse.y"
 {
 		yyvsp[-3]->n_x.v_subs[0]=yyvsp[-1];
 		yyval=yyvsp[-3]; ;
     break;}
 case 13:
-#line 125 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 125 "./parse.y"
 {
 		yyvsp[-5]->n_x.v_subs[0]=yyvsp[-3];
 		yyvsp[-5]->n_x.v_subs[1]=yyvsp[-1];
 		yyval=yyvsp[-5]; ;
     break;}
 case 14:
-#line 129 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 129 "./parse.y"
 {
 		yyvsp[-5]->n_x.v_subs[0]=yyvsp[-3];
 		yyvsp[-5]->n_x.v_subs[1]=yyvsp[-1];
 		yyval=yyvsp[-5]; ;
     break;}
 case 15:
-#line 135 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 135 "./parse.y"
 {
 		if(yyvsp[-7]->comp_value!=F_INDEX)
 			parse_error=PARSE_ERR;
@@ -943,7 +958,7 @@ case 15:
 		yyval=yyvsp[-7]; ;
     break;}
 case 16:
-#line 142 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 142 "./parse.y"
 {
 		if(yyvsp[-7]->comp_value!=F_INDEX)
 			parse_error=PARSE_ERR;
@@ -953,28 +968,28 @@ case 16:
 		yyval=yyvsp[-7]; ;
     break;}
 case 17:
-#line 150 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 150 "./parse.y"
 {
 		(yyvsp[-7])->n_x.v_subs[0]=make_list(yyvsp[-5],yyvsp[-3]);
  		(yyvsp[-7])->n_x.v_subs[1]=yyvsp[-1];
  		yyval=yyvsp[-7];;
     break;}
 case 18:
-#line 154 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 154 "./parse.y"
 {
 		(yyvsp[-7])->n_x.v_subs[0]=make_list(yyvsp[-5],yyvsp[-3]);
  		(yyvsp[-7])->n_x.v_subs[1]=yyvsp[-1];
  		yyval=yyvsp[-7];;
     break;}
 case 19:
-#line 159 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 159 "./parse.y"
 {
 		(yyvsp[-3])->n_x.v_subs[0]=(struct node *)0;
 		(yyvsp[-3])->n_x.v_subs[1]=yyvsp[-1];
 		yyval=yyvsp[-3]; ;
     break;}
 case 20:
-#line 163 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 163 "./parse.y"
 {
 		yyvsp[-3]->comp_value=IF;
 		yyvsp[-3]->n_x.v_subs[0]=yyvsp[-1];
@@ -984,98 +999,98 @@ case 20:
 		yyval=yyvsp[-3]; ;
     break;}
 case 21:
-#line 174 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 174 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 22:
-#line 178 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 178 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 23:
-#line 182 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 182 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 24:
-#line 186 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 186 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 25:
-#line 190 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 190 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 26:
-#line 194 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 194 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 27:
-#line 198 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 198 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 28:
-#line 202 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 202 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 29:
-#line 206 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 206 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 30:
-#line 210 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 210 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 31:
-#line 214 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 214 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 32:
-#line 218 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 218 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 33:
-#line 222 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 222 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 34:
-#line 226 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 226 "./parse.y"
 {
 		if(yyvsp[0]->comp_value==CONST_FLT) {
 			yyvsp[0]->n_x.v_float= -(yyvsp[0]->n_x.v_float);
@@ -1093,53 +1108,53 @@ case 34:
 		} ;
     break;}
 case 35:
-#line 241 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 241 "./parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[0];
 		yyvsp[-1]->n_x.v_subs[1]=(struct node *)0;
 		yyval = yyvsp[-1]; ;
     break;}
 case 36:
-#line 246 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 246 "./parse.y"
 { yyval = yyvsp[-1]; ;
     break;}
 case 37:
-#line 247 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 247 "./parse.y"
 {
 		if(!parse_error)
 			parse_error=NO_CLOSE;
 		;
     break;}
 case 38:
-#line 255 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 255 "./parse.y"
 {
 		if(!parse_error)
 			parse_error=NO_CLOSE;
 		;
     break;}
 case 39:
-#line 263 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 263 "./parse.y"
 { yyval = make_list(yyvsp[0], 0); ;
     break;}
 case 40:
-#line 265 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 265 "./parse.y"
 { yyval = make_list(yyvsp[0], yyvsp[-2]); ;
     break;}
 case 43:
-#line 273 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 273 "./parse.y"
 { yyval=make_list(yyvsp[0], 0); ;
     break;}
 case 44:
-#line 275 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 275 "./parse.y"
 { yyval=make_list(yyvsp[0],yyvsp[-2]); ;
     break;}
 case 45:
-#line 279 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 279 "./parse.y"
 { yyval=yyvsp[0]; ;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 465 "/usr/unsupported/lib/bison.simple"
+#line 487 "/usr/lib/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1335,7 +1350,7 @@ yyerrhandle:
   yystate = yyn;
   goto yynewstate;
 }
-#line 282 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
+#line 282 "./parse.y"
 
 
 void
@@ -1385,12 +1400,12 @@ yylex FUN0()
 	int tmp_ch;
 
 #ifdef TEST
-	if(!instr)
+	if(!instruct)
 		return ERROR;
 #endif
-	while(isspace(*instr))
-		instr++;
-	ch = *instr++;
+	while(isspace(*instruct))
+		instruct++;
+	ch = *instruct++;
 	if(ch=='(' || ch==',' || ch==')')
 		return ch;
 
@@ -1405,8 +1420,8 @@ yylex FUN0()
 	case '7': case '8': case '9': case '.':
 		isflt = (ch=='.');
 
-		begin=instr-1;
-		tmp_str=instr;
+		begin=instruct-1;
+		tmp_str=instruct;
 
 		while(isdigit(*tmp_str) || (!isflt && *tmp_str=='.' && ++isflt))
 			tmp_str++;
@@ -1424,29 +1439,29 @@ yylex FUN0()
 		} else {
 			new->n_x.v_int=astol((char **)(&begin));
 			if(begin!=tmp_str) {
-				begin=instr-1;
+				begin=instruct-1;
 				new->n_x.v_float=astof((char **)(&begin));
 				byte_value=CONST_FLT;
 			} else
 				byte_value=CONST_INT;
 		}
 		ch=L_CONST;
-		instr=begin;
+		instruct=begin;
 		break;
 
 	case '"':
-		begin=instr;
-		while(*instr && *instr!='"') {
-			if(*instr=='\\' && instr[1])
-				instr++;
-			instr++;
+		begin=instruct;
+		while(*instruct && *instruct!='"') {
+			if(*instruct=='\\' && instruct[1])
+				instruct++;
+			instruct++;
 		}
-		if(!*instr) {
+		if(!*instruct) {
 			parse_error=NO_QUOTE;
 			return ERROR;
 		}
-		tmp_str=new->n_x.v_string=(char *)ck_malloc(1+instr-begin);
-		while(begin!=instr) {
+		tmp_str=new->n_x.v_string=(char *)ck_malloc(1+instruct-begin);
+		while(begin!=instruct) {
 			unsigned char n;
 
 			if(*begin=='\\') {
@@ -1471,7 +1486,7 @@ yylex FUN0()
 				*tmp_str++= *begin++;
 		}
 		*tmp_str='\0';
-		instr++;
+		instruct++;
 		byte_value=CONST_STR;
 		ch=L_CONST;
 		break;
@@ -1503,11 +1518,11 @@ yylex FUN0()
 	case '!':
 	case '<':
 	case '>':
-		if(*instr!='=') {
+		if(*instruct!='=') {
 			byte_value = (ch=='<') ? LESS : (ch=='>') ? GREATER : NOT;
 			break;
 		}
-		instr++;
+		instruct++;
 		byte_value = (ch=='<') ? LESSEQ : (ch=='>') ? GREATEQ : NOTEQUAL;
 		ch = (ch=='<') ? LE : (ch=='>') ? GE : NE;
 		break;
@@ -1526,11 +1541,11 @@ yylex FUN0()
 		return ERROR;
 
 	case '#':
-		begin=instr-1;
-		while(*instr && (isalnum(*instr) || *instr=='_'))
-			instr++;
-		ch= *instr;
-		*instr=0;
+		begin=instruct-1;
+		while(*instruct && (isalnum(*instruct) || *instruct=='_'))
+			instruct++;
+		ch= *instruct;
+		*instruct=0;
 		if(!stricmp(begin,tname))
 			byte_value=F_TRUE;
 		else if(!stricmp(begin,fname))
@@ -1552,7 +1567,7 @@ yylex FUN0()
 			new->n_x.v_int=n;
 			byte_value=CONST_ERR;
 		}
-		*instr=ch;
+		*instruct=ch;
 		ch=L_CONST;
 		break;
 
@@ -1561,30 +1576,30 @@ yylex FUN0()
 		   goto bad_chr;
 
 		if(a0 && ch=='@') {
-			begin=instr;
-			while(*instr && (isalpha(*instr) || isdigit(*instr) || *instr=='_'))
-				instr++;
-			n=instr-begin;
+			begin=instruct;
+			while(*instruct && (isalpha(*instruct) || isdigit(*instruct) || *instruct=='_'))
+				instruct++;
+			n=instruct-begin;
 		} else {
-			begin=instr-1;
+			begin=instruct-1;
 			byte_value=parse_cell_or_range(&begin,&(new->n_x.v_rng));
 			if(byte_value) {
 				if((byte_value& ~0x3)==R_CELL)
 					ch=L_CELL;
 				else
 					ch=L_RANGE;
-				instr=begin;
+				instruct=begin;
 				break;
 			}
 
-			while(*instr && (isalpha(*instr) || isdigit(*instr) || *instr=='_'))
-				instr++;
+			while(*instruct && (isalpha(*instruct) || isdigit(*instruct) || *instruct=='_'))
+				instruct++;
 
-			n=instr-begin;
-			while(isspace(*instr))
-				instr++;
+			n=instruct-begin;
+			while(isspace(*instruct))
+				instruct++;
 
-			if(*instr!='(') {
+			if(*instruct!='(') {
 				ch=L_VAR;
 				byte_value=VAR;
 				new->n_x.v_var=find_or_make_var(begin,n);
