@@ -1,12 +1,13 @@
 
-/*  A Bison parser, made from /phydeaux/ni/lord/unsupported/oleo/posixtm.y with Bison version GNU Bison version 1.22
+/*  A Bison parser, made from ./posixtm.y
+ by  Bison version A2.6 (Andrew Consortium)
   */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
 #define	DIGIT	258
 
-#line 19 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
+#line 19 "./posixtm.y"
 
 #ifdef __GNUC__
 #define alloca __builtin_alloca
@@ -39,23 +40,6 @@ time_t mktime ();
 #define psxtparse posixtime_psxtparse
 static int psxtlex ();
 static int psxterror ();
-
-#ifndef YYLTYPE
-typedef
-  struct psxtltype
-    {
-      int timestamp;
-      int first_line;
-      int first_column;
-      int last_line;
-      int last_column;
-      char *text;
-   }
-  psxtltype;
-
-#define YYLTYPE psxtltype
-#endif
-
 #ifndef YYSTYPE
 #define YYSTYPE int
 #endif
@@ -120,9 +104,13 @@ static const short psxtrhs[] = {     8,
 static const short psxtrline[] = { 0,
     56,    85,    92,    99,   110,   113,   122
 };
+#endif
 
-static const char * const psxttname[] = {   "$","error","$illegal.","DIGIT","'.'",
-"date","year","seconds","digitpair",""
+
+#if YYDEBUG != 0
+
+static const char * const psxttname[] = {   "$","error","$undefined.","DIGIT",
+"'.'","date","year","seconds","digitpair", NULL
 };
 #endif
 
@@ -164,14 +152,14 @@ static const short psxtcheck[] = {     2,
      4,     4,     5,     6,     3,     8,     9,     3,     0,     0
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/unsupported/lib/bison.simple"
+#line 3 "/usr/lib/bison.simple"
 
 /* Skeleton output parser for bison,
-   Copyright (C) 1984, 1989, 1990 Bob Corbett and Richard Stallman
+   Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 1, or (at your option)
+   the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -183,6 +171,10 @@ static const short psxtcheck[] = {     2,
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
+/* As a special exception, when this file is copied by Bison into a
+   Bison output file, you may use that output file without restriction.
+   This special exception was added by the Free Software Foundation
+   in version 1.24 of Bison.  */
 
 #ifndef alloca
 #ifdef __GNUC__
@@ -256,10 +248,18 @@ while (0)
 
 #ifdef YYPURE
 #ifdef YYLSP_NEEDED
+#ifdef YYLEX_PARAM
+#define YYLEX		psxtlex(&psxtlval, &psxtlloc, YYLEX_PARAM)
+#else
 #define YYLEX		psxtlex(&psxtlval, &psxtlloc)
+#endif
+#else /* not YYLSP_NEEDED */
+#ifdef YYLEX_PARAM
+#define YYLEX		psxtlex(&psxtlval, YYLEX_PARAM)
 #else
 #define YYLEX		psxtlex(&psxtlval)
 #endif
+#endif /* not YYLSP_NEEDED */
 #endif
 
 /* If nonreentrant, generate the variables here */
@@ -307,14 +307,14 @@ int psxtparse (void);
 #endif
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
-#define __psxt_bcopy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
+#define __psxt_memcpy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
 #ifndef __cplusplus
 
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__psxt_bcopy (from, to, count)
+__psxt_memcpy (from, to, count)
      char *from;
      char *to;
      int count;
@@ -332,7 +332,7 @@ __psxt_bcopy (from, to, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__psxt_bcopy (char *from, char *to, int count)
+__psxt_memcpy (char *from, char *to, int count)
 {
   register char *f = from;
   register char *t = to;
@@ -345,9 +345,24 @@ __psxt_bcopy (char *from, char *to, int count)
 #endif
 #endif
 
-#line 184 "/usr/unsupported/lib/bison.simple"
+#line 192 "/usr/lib/bison.simple"
+
+/* The user can define YYPARSE_PARAM as the name of an argument to be passed
+   into psxtparse.  The argument should have type void *.
+   It should actually point to an object.
+   Grammar actions can access the variable by casting it
+   to the proper pointer type.  */
+
+#ifdef YYPARSE_PARAM
+#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
+#else
+#define YYPARSE_PARAM
+#define YYPARSE_PARAM_DECL
+#endif
+
 int
-psxtparse()
+psxtparse(YYPARSE_PARAM)
+     YYPARSE_PARAM_DECL
 {
   register int psxtstate;
   register int psxtn;
@@ -463,12 +478,12 @@ psxtnewstate:
       if (psxtstacksize > YYMAXDEPTH)
 	psxtstacksize = YYMAXDEPTH;
       psxtss = (short *) alloca (psxtstacksize * sizeof (*psxtssp));
-      __psxt_bcopy ((char *)psxtss1, (char *)psxtss, size * sizeof (*psxtssp));
+      __psxt_memcpy ((char *)psxtss1, (char *)psxtss, size * sizeof (*psxtssp));
       psxtvs = (YYSTYPE *) alloca (psxtstacksize * sizeof (*psxtvsp));
-      __psxt_bcopy ((char *)psxtvs1, (char *)psxtvs, size * sizeof (*psxtvsp));
+      __psxt_memcpy ((char *)psxtvs1, (char *)psxtvs, size * sizeof (*psxtvsp));
 #ifdef YYLSP_NEEDED
       psxtls = (YYLTYPE *) alloca (psxtstacksize * sizeof (*psxtlsp));
-      __psxt_bcopy ((char *)psxtls1, (char *)psxtls, size * sizeof (*psxtlsp));
+      __psxt_memcpy ((char *)psxtls1, (char *)psxtls, size * sizeof (*psxtlsp));
 #endif
 #endif /* no psxtoverflow */
 
@@ -629,7 +644,7 @@ psxtreduce:
   switch (psxtn) {
 
 case 1:
-#line 62 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
+#line 62 "./posixtm.y"
 {
 	         if (psxtvsp[-5] >= 1 && psxtvsp[-5] <= 12)
 		   t.tm_mon = psxtvsp[-5] - 1;
@@ -654,7 +669,7 @@ case 1:
 	       ;
     break;}
 case 2:
-#line 85 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
+#line 85 "./posixtm.y"
 {
                    t.tm_year = psxtvsp[0];
 		   /* Deduce the century based on the year.
@@ -664,7 +679,7 @@ case 2:
 		 ;
     break;}
 case 3:
-#line 92 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
+#line 92 "./posixtm.y"
 {
                             t.tm_year = psxtvsp[-1] * 100 + psxtvsp[0];
 			    if (t.tm_year < 1900) {
@@ -674,7 +689,7 @@ case 3:
 			  ;
     break;}
 case 4:
-#line 99 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
+#line 99 "./posixtm.y"
 {
                     time_t now;
 		    struct tm *tmp;
@@ -686,13 +701,13 @@ case 4:
 		  ;
     break;}
 case 5:
-#line 110 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
+#line 110 "./posixtm.y"
 {
                         t.tm_sec = 0;
 		      ;
     break;}
 case 6:
-#line 113 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
+#line 113 "./posixtm.y"
 {
 	                  if (psxtvsp[0] >= 0 && psxtvsp[0] <= 61)
 			    t.tm_sec = psxtvsp[0];
@@ -702,14 +717,14 @@ case 6:
 			;
     break;}
 case 7:
-#line 122 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
+#line 122 "./posixtm.y"
 {
                           psxtval = psxtvsp[-1] * 10 + psxtvsp[0];
 			;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 465 "/usr/unsupported/lib/bison.simple"
+#line 487 "/usr/lib/bison.simple"
 
   psxtvsp -= psxtlen;
   psxtssp -= psxtlen;
@@ -905,7 +920,7 @@ psxterrhandle:
   psxtstate = psxtn;
   goto psxtnewstate;
 }
-#line 126 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
+#line 126 "./posixtm.y"
 
 static int
 psxtlex ()
