@@ -23,6 +23,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #undef NULL
 #endif
 
+#ifndef __linux__
 int
 vfprintf (fp, s, ap)
      FILE *fp;
@@ -34,6 +35,4 @@ vfprintf (fp, s, ap)
   len = _doprnt (s, ap, fp);
   return (ferror (fp) ? EOF : len);
 }
-
-
-
+#endif /* not __linux__ */
