@@ -23,6 +23,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #undef NULL
 #endif
 
+#ifndef __linux__
 int
 vsprintf (into, s, ap)
      char *into;
@@ -44,3 +45,4 @@ vsprintf (into, s, ap)
   *f._ptr = 0;
   return (ret);
 }
+#endif /* not __linux__ */
